@@ -41,11 +41,12 @@ class ExtensionManagerDialog:
 		
 		self.dlg = self.wTree.get_widget("ExtensionManagerDialog")
 		self.tree = self.wTree.get_widget("treeviewExtensions")
+		self.eb = self.wTree.get_widget("descriptionEventBox")
+		self.description = self.wTree.get_widget("ExtensionDescription")
 		self.prefs_button = self.wTree.get_widget("buttonPreferences")
 		
 		self.AddColumn("Enabled", 0, 'toggle')
-		self.AddColumn("Name", 1, 'text', 25)
-		self.AddColumn("Description", 2, 'text', 25)
+		self.AddColumn("Name", 1, 'text', 30)
 		self.AddColumn("Version", 3, 'text', 7)
 
 		self.model = gtk.ListStore(bool, str, str, str, str, bool)
@@ -54,6 +55,7 @@ class ExtensionManagerDialog:
 		for extension in self.parent.extensionManager.GetExtensions():
 			self.model.append((extension["enabled"], extension["name"], extension["description"], extension["version"], extension["filename"], extension["preferences"]))
 
+
 		self.dlg.set_transient_for(self.parent.window)
 		self.dlg.show()
 	
@@ -137,18 +139,23 @@ class ExtensionManagerDialog:
 	def OnSelect(self, tree):
 		"""
 		When an Extension is selected, enables/disables the preferences button
-		according to the reported Extension capabilities.
+		according to the reported Extension capabilities and updates the
+		description label.
 		
 		Parameters:
 			tree -- GTKTreeView holding the Extensions's representation.
 		"""
+		descr_text = ""
 		selection = self.tree.get_selection().get_selected()[1]
-		preferences = self.model.get_value(selection, 5)
-		if preferences:
-			self.prefs_button.set_sensitive(True)
-		else:
-			self.prefs_button.set_sensitive(False)
+		if selection:
+			preferences = self.model.get_value(selection, 5)
+			if preferences:
+				self.prefs_button.set_sensitive(True)
+			else:
+				self.prefs_button.set_sensitive(False)
 		
+			descr_text = self.model.get_value(selection, 2)
+		self.description.set_text(descr_text)
 	#_____________________________________________________________________
 	
 	def OnAdd(self, button):
