@@ -15,6 +15,7 @@
 import pygst
 pygst.require("0.10")
 import gst
+import PlatformUtils
 import os, time, shutil
 import urlparse # To split up URI's
 import gobject
@@ -199,7 +200,7 @@ class Instrument(gobject.GObject):
 		self.volumeElement.link(self.levelElement)
 		self.levelElement.link(self.panElement)	
 		self.panElement.link(self.resample)
-		
+
 		self.playghostpad = gst.GhostPad("src", self.resample.get_pad("src"))
 		self.playbackbin.add_pad(self.playghostpad)
 		
@@ -489,7 +490,7 @@ class Instrument(gobject.GObject):
 		
 		ext = Globals.settings.recording["file_extension"]
 		filename = "%s_%d.%s" % (Globals.FAT32SafeFilename(self.name), event.id, ext)
-		event.file = os.path.join(self.project.audio_path, filename)
+		event.file = filename
 		event.levels_file = filename + Event.Event.LEVELS_FILE_EXTENSION
 		
 		inc = IncrementalSave.NewEvent(self.id, filename, event.start, event.id, recording=True)
@@ -541,7 +542,7 @@ class Instrument(gobject.GObject):
 		
 		Parameters:
 			start -- the offset time in seconds for the first event.
-			fileList -- paths or URIs to the Event files.
+			fileList -- URIs to the Event files.
 			copyfile --	True = copy the files to Project's audio directory.
 						False = don't copy the files to the Project's audio directory.
 		"""
@@ -555,6 +556,7 @@ class Instrument(gobject.GObject):
 			# Parse the uri, and continue only if it is pointing to a local file
 			(scheme, domain, file, params, query, fragment) = urlparse.urlparse(uri, "file", False)
 			if scheme == "file":
+				file = PlatformUtils.url2pathname(file)
 				event = self.addEventFromFile(start, file, copyFile, _undoAction_=undoAction)
 			else:
 				event = self.addEventFromURL(start, uri, _undoAction_=undoAction)
@@ -604,7 +606,7 @@ class Instrument(gobject.GObject):
 			inc = IncrementalSave.NewEvent(self.id, newfile, start, event_id)
 			self.project.SaveIncrementalAction(inc)
 			
-			file = audio_file
+			file = newfile
 		else:
 			inc = IncrementalSave.NewEvent(self.id, file, start, event_id)
 			self.project.SaveIncrementalAction(inc)
@@ -617,8 +619,7 @@ class Instrument(gobject.GObject):
 		if duration and levels_file:
 			ev.duration = duration
 			ev.levels_file = levels_file
-			levels_path = os.path.join(self.project.levels_path, levels_file)
-			ev.levels_list.fromfile(levels_path)
+			ev.levels_list.fromfile(ev.GetAbsLevelsFile())
 			# update properties and position when duration changes.
 			ev.MoveButDoNotOverlap(ev.start)
 			ev.SetProperties()
@@ -657,7 +658,7 @@ class Instrument(gobject.GObject):
 		self.project.deleteOnCloseAudioFiles.append(audio_file)
 		
 		# Create the event now so we can return it, and fill in the file later
-		ev = Event.Event(self, audio_file, event_id, url)
+		ev = Event.Event(self, newfile, event_id, url)
 		ev.start = start
 		ev.name = os.path.split(audio_file)[1]
 		ev.isDownloading = True
