@@ -15,7 +15,7 @@ import pygst
 pygst.require("0.10")
 import gst
 import gobject
-import os
+import os, os.path
 import gzip
 import re
 
@@ -27,6 +27,7 @@ import Instrument, Event
 import Utils
 import AudioBackend
 import ProjectManager
+import PlatformUtils
 
 #=========================================================================
 
@@ -102,6 +103,7 @@ class Project(gobject.GObject):
 		self.instruments = []		#the list of instruments held by this project
 		self.graveyard = []			# The place where deleted instruments are kept, to later be retrieved by undo functions
 		#used to delete copied audio files if the event that uses them is not saved in the project file
+		#also contains paths to levels_data files corresponding to those audio files
 		self.deleteOnCloseAudioFiles = []	# WARNING: any paths in this list will be deleted on exit!
 		self.clipboardList = []		#The list containing the events to cut/copy
 		self.viewScale = 25.0		#View scale as pixels per second
@@ -233,8 +235,6 @@ class Project(gobject.GObject):
 			self.transport.Play(newAudioState)
 		
 		Globals.debug("just set state to PAUSED")
-
-		Globals.PrintPipelineDebug("Play Pipeline:", self.mainpipeline)
 		
 	#_____________________________________________________________________
 
@@ -262,8 +262,6 @@ class Project(gobject.GObject):
 
 		self.TerminateRecording()
 		
-		Globals.PrintPipelineDebug("PIPELINE AFTER STOP:", self.mainpipeline)
-		
 	#_____________________________________________________________________
 
 	def TerminateRecording(self):
@@ -392,13 +390,20 @@ class Project(gobject.GObject):
 				else:
 					capsString = "audioconvert"
 					
-				pipe = "%s ! %s ! level name=recordlevel interval=%d" +\
-							" ! audioconvert ! %s ! filesink location=%s"
-				pipe %= (recordString, capsString, event.LEVEL_INTERVAL * gst.SECOND, encodeString, event.file.replace(" ", "\ "))
+				# TODO: get rid of this entire string; do it manually
+				pipe = "%s ! %s ! level name=recordlevel ! audioconvert ! %s ! filesink name=sink"
+				pipe %= (recordString, capsString, encodeString)
 				
 				Globals.debug("Using pipeline: %s" % pipe)
 				
 				recordingbin = gst.parse_bin_from_description(pipe, False)
+				
+				filesink = recordingbin.get_by_name("sink")
+				level = recordingbin.get_by_name("recordlevel")
+				
+				filesink.set_property("location", event.GetAbsFile())
+				level.set_property("interval", int(event.LEVEL_INTERVAL * gst.SECOND))
+				
 				#update the levels in real time
 				handle = self.bus.connect("message::element", event.recording_bus_level)
 				
@@ -605,15 +610,21 @@ class Project(gobject.GObject):
 			if instr.inTrack == index:
 				event = instr.GetRecordingEvent()
 				
+				# TODO: get rid of string concatentation
 				encodeString = Globals.settings.recording["fileformat"]
-				pipe = "queue ! audioconvert ! level name=recordlevel interval=%d !" +\
-							"audioconvert ! %s ! filesink location=%s"
-				pipe %= (event.LEVEL_INTERVAL * gst.SECOND, encodeString, event.file.replace(" ", "\ "))
+				pipe = "queue ! audioconvert ! level name=recordlevel ! audioconvert ! %s ! filesink name=sink"
+				pipe %= encodeString
 				
 				encodeBin = gst.parse_bin_from_description(pipe, True)
 				bin.add(encodeBin)
 				pad.link(encodeBin.get_pad("sink"))
 				
+				filesink = bin.get_by_name("sink")
+				level = bin.get_by_name("recordlevel")
+				
+				filesink.set_property("location", event.GetAbsFile())
+				level.set_property("interval", int(event.LEVEL_INTERVAL * gst.SECOND))
+				
 				handle = self.bus.connect("message::element", event.recording_bus_level)
 				
 				# since we are adding the encodebin to an already playing pipeline, sync up there states
@@ -812,6 +823,8 @@ class Project(gobject.GObject):
 			os.remove(path + "~")
 		else:
 			#if the saving doesn't fail, move it to the proper location
+			if os.path.exists(path):
+				os.remove(path)
 			os.rename(path + "~", path)		
 		
 		self.emit("undo")
@@ -1306,10 +1319,12 @@ class Project(gobject.GObject):
 		"""
 		if not undoAction:
 			undoAction = self.NewAtomicUndoAction()
-		
+	
+		uris = [PlatformUtils.pathname2url(filename) for filename in fileList]
+
 		name, type, pixbuf, path = [x for x in Globals.getCachedInstruments() if x[1] == "audiofile"][0]
 		instr = self.AddInstrument(name, type, _undoAction_=undoAction)
-		instr.AddEventsFromList(0, fileList, copyFile, undoAction)
+		instr.AddEventsFromList(0, uris, copyFile, undoAction)
 	
 	#_____________________________________________________________________
 	
@@ -1532,6 +1547,26 @@ class Project(gobject.GObject):
 	
 	#_____________________________________________________________________
 	
+	def SetProjectSinkDevice(self):
+		"""
+		Grabs the sink element device based on the Global preferences, and sets
+		the pipeline to use that device.
+		"""
+		if self.audioState != self.AUDIO_EXPORTING and \
+		   self.audioState != self.AUDIO_STOPPED:
+			self.Stop()
+			
+		if not self.masterSink:
+			return
+		
+		sinkElement = self.masterSink.sinks().next()
+		if hasattr(sinkElement.props, "device"):
+			outdevice = Globals.settings.playback["device"]
+			Globals.debug("Changing output device: %s" % outdevice)
+			sinkElement.set_property("device", outdevice)
+		
+	#_____________________________________________________________________
+	
 	def MakeProjectSink(self):
 		"""
 		Contructs a GStreamer sink element (or bin with ghost pads) for the 
@@ -1586,10 +1621,30 @@ class Project(gobject.GObject):
 		fileList = []
 		for instrument in self.instruments:
 			for event in instrument.events:
-				fileList.append(event.file)
+				fileList.append(event.GetAbsFile())
 		return fileList
 		
 	#____________________________________________________________________	
+	
+	def GetLocalAudioFilenames(self):
+		fileList = []
+		for instrument in self.instruments:
+			for event in instrument.events:
+				if not os.path.isabs(event.file):
+					fileList.append(event.file)
+		return fileList
+	
+	#____________________________________________________________________	
+	
+	def GetLevelsFilenames(self):
+		fileList = []
+		for instrument in self.instruments:
+			for event in instrument.events:
+				fileList.append(event.levels_file)
+		return fileList
+	
+	#____________________________________________________________________	
+	
 
 	def SetName(self, name):
 		if self.name != name:
