@@ -39,9 +39,12 @@ class TimeView(gtk.EventBox):
 		self.add(self.timeViewLabel)
 		self.project = project
 		# Listen for bpm and time sig changes
-		self.project.AddListener(self)
-		# Listen for playback position changes
-		self.project.transport.AddListener(self)
+		self.project.connect("bpm", self.OnProjectTime)
+		self.project.connect("time-signature", self.OnProjectTime)
+		# Listen for playback position and mode changes
+		self.project.transport.connect("transport-mode", self.OnTransportMode)
+		self.project.transport.connect("position", self.OnTransportPosition)
+		
 		self.UpdateTime()
 		self.tmtip = gtk.Tooltips()
 		self.tmtip.set_tip(self, _("Double click to change the time format"), None)
@@ -64,19 +67,40 @@ class TimeView(gtk.EventBox):
 			
 	#_____________________________________________________________________
 	
-	def OnStateChanged(self, obj, change=None, *extra):
+	def OnProjectTime(self, project):
 		"""
-		Called when a change of state is signalled by any of the
-		objects this view is 'listening' to.
-		Updates the time label.
+		Callback for when the project's time related properties
+		(bpm and time signature) change.
 		
 		Parameters:
-			obj -- object changing state.
-			change -- the change which has occured.
-			extra -- extra parameters passed by the caller.
+			project -- The project instance that send the signal.
 		"""
-		if change in ("position", "transport-mode", "bpm", "time-signature"):
-			self.UpdateTime()
+		self.UpdateTime()
+	
+	#_____________________________________________________________________
+	
+	def OnTransportMode(self, transportManager, mode):
+		"""
+		Callback for signal when the transport mode changes.
+		
+		Parameters:
+			transportManager -- the TransportManager instance that send the signal.
+			mode -- the mode type that the transport changed to.
+		"""
+		self.UpdateTime()
+	
+	#_____________________________________________________________________
+	
+	def OnTransportPosition(self, transportManager, extraString):
+		"""
+		Callback for signal when the transport position changes.
+		
+		Parameters:
+			transportManager -- the TransportManager instance that send the signal.
+			extraString -- a string specifying the extra action details. i.e. "stop-action"
+					means that the position changed because the user hit stop.
+		"""
+		self.UpdateTime()
 	
 	#_____________________________________________________________________
 
